You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mesos.apache.org by ji...@apache.org on 2015/06/20 00:44:19 UTC

[3/3] mesos git commit: Fixed a bug in test filter that prevent some tests from being launched.

Fixed a bug in test filter that prevent some tests from being launched.

Review: https://reviews.apache.org/r/35671


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/68505cd0
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/68505cd0
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/68505cd0

Branch: refs/heads/master
Commit: 68505cd0a478a96393ca988e74f99460333f5e45
Parents: ce1c6e2
Author: Jie Yu <yu...@gmail.com>
Authored: Fri Jun 19 15:20:07 2015 -0700
Committer: Jie Yu <yu...@gmail.com>
Committed: Fri Jun 19 15:44:00 2015 -0700

----------------------------------------------------------------------
 src/tests/environment.cpp | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/68505cd0/src/tests/environment.cpp
----------------------------------------------------------------------
diff --git a/src/tests/environment.cpp b/src/tests/environment.cpp
index 2b6bc0c..f111a77 100644
--- a/src/tests/environment.cpp
+++ b/src/tests/environment.cpp
@@ -236,8 +236,10 @@ public:
   bool disable(const ::testing::TestInfo* test) const
   {
 #ifdef WITH_NETWORK_ISOLATOR
-    // PortMappingIsolatorProcess doesn't suport multiple slaves.
-    if (matches(test, "MultipleSlaves")) {
+    // PortMappingIsolatorProcess doesn't suport test
+    // 'SlaveRecoveryTest.MultipleSlaves'.
+    if (matches(test, "SlaveRecoveryTest") &&
+        matches(test, "MultipleSlaves")) {
       return true;
     }
 #endif